@@ -7,7 +7,7 @@ use Log::Any '$log';
 
 use Parse::Number::ID qw(parse_number_id);
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 extends 'Finance::Bank::ID::Base';
 
@@ -449,7 +449,7 @@ Finance::Bank::ID::BPRKS - Check your BPR KS accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.02 of Finance::Bank::ID::BPRKS (from Perl distribution Finance-Bank-ID-BPRKS), released on 2014-05-17.
+This document describes version 0.03 of Finance::Bank::ID::BPRKS (from Perl distribution Finance-Bank-ID-BPRKS), released on 2015-04-28.
 
 =head1 SYNOPSIS
 
@@ -533,9 +533,6 @@ GUARANTEE>, explicit or implied.
 
 Most methods die() when encountering errors, so you can use eval() to trap them.
 
-This module uses L<Log::Any>, so you can see more debugging statements on your
-screen, log files, etc. See the Log::Any documentation on how to do that.
-
 Full response headers and bodies are dumped to a separate logger. See
 documentation on C<new()> below and the sample script in examples/ subdirectory
 in the distribution.
@@ -736,7 +733,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Finance-Ba
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Finance-Bank-ID-BPRKS>.
+Source repository is at L<https://github.com/perlancar/perl-Finance-Bank-ID-BPRKS>.
 
 =head1 BUGS
 
@@ -748,11 +745,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
